# streamlit-week-selector

this component offers you to input and choose single week from year

## Installation instructions 

```sh
pip install streamlit-week-selector
```

## Usage instructions

```python
import streamlit as st

from streamlit_week_selector import streamlit_week_selector

value = streamlit_week_selector()

st.write(value)
